package zipfs

import "golang.org/x/tools/godoc/vfs/zipfs"

Package zipfs file provides an implementation of the FileSystem interface based on the contents of a .zip file.

Assumptions:

Index

Functions

func New

func New(rc *zip.ReadCloser, name string) vfs.FileSystem

Source Files

zipfs.go

Version
v0.1.0-deprecated (latest)
Published
Sep 4, 2025
Platform
linux/amd64
Imports
11 packages
Last checked
3 hours ago

Tools for package owners.